PCB Environment: AlignedTHPAllocator< T > Struct Template Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Types | Public Member Functions
AlignedTHPAllocator< T > Struct Template Reference

## Public Types
using | value_type = T

## Public Member Functions
template<class U>
constexpr | AlignedTHPAllocator (const AlignedTHPAllocator< U > &) noexcept
T * | allocate (std::size_t n)
void | deallocate (T *p, std::size_t n) noexcept

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Util/HugePageAllocator.hpp